epistasis\.sampling package
===========================

epistasis\.sampling\.bayesian module
------------------------------------

.. automodule:: epistasis.sampling.bayesian
    :members:
    :undoc-members:
    :show-inheritance:
